import { _ as _applyDecoratedDescriptor, a as _initializerDefineProperty } from '../_rollupPluginBabelHelpers-ad98503d.js';
import { setComponentTemplate } from '@ember/component';
import { hbs } from 'ember-cli-htmlbars';
import Component from '@glimmer/component';
import { tracked } from '@glimmer/tracking';
import { action } from '@ember/object';
import './animated-tools.css';

var TEMPLATE = hbs`{{#unless this.isHidden}}
  <div class="animated-tools {{if this.isOpen "is-open"}}" ...attributes>
    <div class="animated-tools-launcher" role="button" {{on "click" this.toggle}}>
      <MotionIndicator />
      ⏱{{! <--- there's an emoji here, in case your editor doesn't show it }}
    </div>
    <div class="animated-tools-panel">
      <TimeControl />
    </div>
  </div>
{{/unless}}
`;

var _class, _descriptor, _descriptor2;
let AnimatedTools = (_class = class AnimatedTools extends Component {
  // always hidden in fastboot
  constructor() {
    super(...arguments);

    _initializerDefineProperty(this, "isOpen", _descriptor, this);

    _initializerDefineProperty(this, "isHidden", _descriptor2, this);

    if (typeof FastBoot === 'undefined') {
      this.isOpen = !!localStorage.getItem('animated-tools-open'); // hidden if we're using hideUntilKeys and the keys haven't been pressed yet.

      this.isHidden = this.args.hideUntilKeys && !localStorage.getItem('animated-tools-activated');

      if (this.args.hideUntilKeys) {
        this._keyListener = this._keyListener.bind(this);
        document.addEventListener('keydown', this._keyListener);
      }
    }
  }

  willDestroy() {
    super.willDestroy(...arguments);

    if (typeof FastBoot === 'undefined' && this.args.hideUntilKeys) {
      document.removeEventListener('keydown', this._keyListener);
    }
  }

  get tests() {
    if (!this.args.hideUntilKeys) {
      return null;
    }

    return this.args.hideUntilKeys.split('-').map(part => {
      if (part === 'Ctrl') {
        return event => event.ctrlKey;
      }

      if (part === 'Alt') {
        return event => event.altKey;
      }

      if (part === 'Shift') {
        return event => event.shiftKey;
      }

      return event => event.code === part;
    });
  }

  _keyListener(event) {
    if (this.tests.every(test => test(event))) {
      if (localStorage.getItem('animated-tools-activated')) {
        this.deactivate();
      } else {
        this.activate();
        this.open();
      }
    }
  }

  toggle() {
    if (this.isOpen) {
      this.hide();
    } else {
      this.open();
    }
  }

  open() {
    localStorage.setItem('animated-tools-open', true);
    this.isOpen = true;
  }

  hide() {
    localStorage.removeItem('animated-tools-open');
    this.isOpen = false;
  }

  activate() {
    localStorage.setItem('animated-tools-activated', true);
    this.isHidden = false;
  }

  deactivate() {
    localStorage.removeItem('animated-tools-activated');
    this.isHidden = true;
  }

}, (_descriptor = _applyDecoratedDescriptor(_class.prototype, "isOpen", [tracked], {
  configurable: true,
  enumerable: true,
  writable: true,
  initializer: function () {
    return false;
  }
}), _descriptor2 = _applyDecoratedDescriptor(_class.prototype, "isHidden", [tracked], {
  configurable: true,
  enumerable: true,
  writable: true,
  initializer: function () {
    return true;
  }
}), _applyDecoratedDescriptor(_class.prototype, "toggle", [action], Object.getOwnPropertyDescriptor(_class.prototype, "toggle"), _class.prototype)), _class);
setComponentTemplate(TEMPLATE, AnimatedTools);

export { AnimatedTools as default };
