import { _ as _applyDecoratedDescriptor, a as _initializerDefineProperty, b as _defineProperty } from '../_rollupPluginBabelHelpers-ad98503d.js';
import { setComponentTemplate } from '@ember/component';
import { hbs } from 'ember-cli-htmlbars';
import Component from '@glimmer/component';
import { tracked } from '@glimmer/tracking';
import TimeControl from 'ember-animated/test-support/time-control';
import { action } from '@ember/object';
import { htmlSafe } from '@ember/template';
import { task } from 'ember-animated';
import { inject } from '@ember/service';

var TEMPLATE = hbs`<div class="eat-time-control">
  <div>
    <label>Speed {{-eat-rounded this.speedPercent}}%</label>
    <div>
      <div class="eat-time-control--tick-marks">
        {{#each this.tickMarks as |tickMark|}}
          {{! template-lint-disable no-inline-styles }}
          <div style={{tickMark.position}} role="button" {{on "click" (fn this.tickMarkChosen tickMark)}}>
            <span>{{tickMark.text}}</span>
          </div>
        {{/each}}
      </div>
      <input
        class="eat-time-control--slider"
        type="range"
        value={{this.logSpeed}}
        min="0"
        max="200"
        step="1"
        aria-label="Speed slider"
        oninput={{this.updateLogSpeed}}
      >
    </div>
  </div>
</div>`;

var _dec, _dec2, _class, _descriptor, _descriptor2, _descriptor3;

function toLogSpeed(speedPercent) {
  let percent = speedPercent;

  if (percent <= 1) {
    // Log of zero is infinity. Log of 1% is as low as we go, which
    // counts as paused for us.
    percent = 1;
  }

  return 200 * Math.log(percent) / Math.log(200);
}

function fromLogSpeed(logSpeed) {
  let percent = Math.exp(Math.log(200) * logSpeed / 200);

  if (percent <= 1) {
    percent = 0;
  }

  return percent;
}

let TimeControlComponent = (_dec = inject('-ea-motion'), _dec2 = task(function* (speed) {
  if (speed === 100) {
    // at normal speed, we want to disable our time control
    // entirely. This means we won't intefere with things like
    // acceptance tests that may already want to take over the
    // timing.
    //
    // But if there's an animation in progress, we must wait until
    // it's done. Otherwise there will be a jarring jump from our
    // fake time to the real time.
    if (this.time) {
      this.time.runAtSpeed(1);
      this.speedPercent = speed;
      yield this.motionService.waitUntilIdle?.perform();
      this.time.finished();
      this.time = null;
    }
  } else {
    if (!this.time) {
      this.time = new TimeControl();
    }

    if (speed === 0) {
      this.time.pause();
    } else {
      this.time.runAtSpeed(speed / 100);
    }

    this.speedPercent = speed;
  }
}).restartable(), (_class = class TimeControlComponent extends Component {
  constructor(...args) {
    super(...args);

    _initializerDefineProperty(this, "speedPercent", _descriptor, this);

    _initializerDefineProperty(this, "motionService", _descriptor2, this);

    _defineProperty(this, "tickMarks", [{
      value: 0,
      text: 'Paused'
    }, {
      value: 5,
      text: '5%'
    }, {
      value: 10,
      text: '10%'
    }, {
      value: 25,
      text: '25%'
    }, {
      value: 50,
      text: '50%'
    }, {
      value: 100,
      text: '100%'
    }].map(entry => {
      entry.position = htmlSafe(`left: ${toLogSpeed(entry.value) / 2}%`);
      return entry;
    }));

    _initializerDefineProperty(this, "_speedSetter", _descriptor3, this);
  }

  get logSpeed() {
    return toLogSpeed(this.speedPercent);
  }

  // didInsertElement() {
  //   // weirdly, ember is not initializing this for me correctly
  //   this.element.querySelector('input').value = this.logSpeed;
  // }
  willDestroy() {
    super.willDestroy();

    if (this.time) {
      this.time.finished();
      this.time = null;
    }
  }

  updateLogSpeed(event) {
    this._setSpeed(fromLogSpeed(event.target.valueAsNumber));
  }

  tickMarkChosen(tickMark) {
    this._setSpeed(tickMark.value);
  }

  _setSpeed(speed) {
    this._speedSetter.perform(speed);
  }

}, (_descriptor = _applyDecoratedDescriptor(_class.prototype, "speedPercent", [tracked], {
  configurable: true,
  enumerable: true,
  writable: true,
  initializer: function () {
    return 100;
  }
}), _descriptor2 = _applyDecoratedDescriptor(_class.prototype, "motionService", [_dec], {
  configurable: true,
  enumerable: true,
  writable: true,
  initializer: null
}), _applyDecoratedDescriptor(_class.prototype, "updateLogSpeed", [action], Object.getOwnPropertyDescriptor(_class.prototype, "updateLogSpeed"), _class.prototype), _applyDecoratedDescriptor(_class.prototype, "tickMarkChosen", [action], Object.getOwnPropertyDescriptor(_class.prototype, "tickMarkChosen"), _class.prototype), _descriptor3 = _applyDecoratedDescriptor(_class.prototype, "_speedSetter", [_dec2], {
  configurable: true,
  enumerable: true,
  writable: true,
  initializer: null
})), _class));
setComponentTemplate(TEMPLATE, TimeControlComponent);

export { TimeControlComponent as default };
